@@ -27,17 +27,17 @@ public class vtkOpenGLHardwareSelector extends vtkHardwareSelector
   public void RenderCompositeIndex(int id0)
     { RenderCompositeIndex_4(id0); }
 
-  private native void RenderAttributeId_5(int id0);
-  public void RenderAttributeId(int id0)
-    { RenderAttributeId_5(id0); }
-
-  private native void RenderProcessId_6(int id0);
+  private native void RenderProcessId_5(int id0);
   public void RenderProcessId(int id0)
-    { RenderProcessId_6(id0); }
+    { RenderProcessId_5(id0); }
 
-  private native void BeginSelection_7();
+  private native void BeginSelection_6();
   public void BeginSelection()
-    { BeginSelection_7(); }
+    { BeginSelection_6(); }
+
+  private native void EndSelection_7();
+  public void EndSelection()
+    { EndSelection_7(); }
 
   public vtkOpenGLHardwareSelector() { super(); }
 
